==> tencentcloud-sdk-java-3.1.209-sources.jar: com/tencentcloudapi/ccc/v20200210/models/DescribePSTNActiveSessionListRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ccc.v20200210.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribePSTNActiveSessionListRequest extends AbstractModel{

    /**
    * 应用 ID
    */
    @SerializedName("SdkAppId")
    @Expose
    private Long SdkAppId;

    /**
    * 数据偏移
    */
    @SerializedName("Offset")
    @Expose
    private Long Offset;

    /**
    * 返回的数据条数，最大 25
    */
    @SerializedName("Limit")
    @Expose
    private Long Limit;

    /**
     * Get 应用 ID 
     * @return SdkAppId 应用 ID
     */
    public Long getSdkAppId() {
        return this.SdkAppId;
    }

    /**
     * Set 应用 ID
     * @param SdkAppId 应用 ID
     */
    public void setSdkAppId(Long SdkAppId) {
        this.SdkAppId = SdkAppId;
    }

    /**
     * Get 数据偏移 
     * @return Offset 数据偏移
     */
    public Long getOffset() {
        return this.Offset;
    }

    /**
     * Set 数据偏移
     * @param Offset 数据偏移
     */
    public void setOffset(Long Offset) {
        this.Offset = Offset;
    }

    /**
     * Get 返回的数据条数，最大 25 
     * @return Limit 返回的数据条数，最大 25
     */
    public Long getLimit() {
        return this.Limit;
    }

    /**
     * Set 返回的数据条数，最大 25
     * @param Limit 返回的数据条数，最大 25
     */
    public void setLimit(Long Limit) {
        this.Limit = Limit;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "SdkAppId", this.SdkAppId);
        this.setParamSimple(map, prefix + "Offset", this.Offset);
        this.setParamSimple(map, prefix + "Limit", this.Limit);

    }
}

==> tencentcloud-sdk-java-3.1.268-sources.jar: com/tencentcloudapi/ccc/v20200210/models/DescribePSTNActiveSessionListRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ccc.v20200210.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribePSTNActiveSessionListRequest extends AbstractModel{

    /**
    * 应用 ID
    */
    @SerializedName("SdkAppId")
    @Expose
    private Long SdkAppId;

    /**
    * 数据偏移
    */
    @SerializedName("Offset")
    @Expose
    private Long Offset;

    /**
    * 返回的数据条数，最大 25
    */
    @SerializedName("Limit")
    @Expose
    private Long Limit;

    /**
     * Get 应用 ID 
     * @return SdkAppId 应用 ID
     */
    public Long getSdkAppId() {
        return this.SdkAppId;
    }

    /**
     * Set 应用 ID
     * @param SdkAppId 应用 ID
     */
    public void setSdkAppId(Long SdkAppId) {
        this.SdkAppId = SdkAppId;
    }

    /**
     * Get 数据偏移 
     * @return Offset 数据偏移
     */
    public Long getOffset() {
        return this.Offset;
    }

    /**
     * Set 数据偏移
     * @param Offset 数据偏移
     */
    public void setOffset(Long Offset) {
        this.Offset = Offset;
    }

    /**
     * Get 返回的数据条数，最大 25 
     * @return Limit 返回的数据条数，最大 25
     */
    public Long getLimit() {
        return this.Limit;
    }

    /**
     * Set 返回的数据条数，最大 25
     * @param Limit 返回的数据条数，最大 25
     */
    public void setLimit(Long Limit) {
        this.Limit = Limit;
    }

    public DescribePSTNActiveSessionListRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribePSTNActiveSessionListRequest(DescribePSTNActiveSessionListRequest source) {
        if (source.SdkAppId != null) {
            this.SdkAppId = new Long(source.SdkAppId);
        }
        if (source.Offset != null) {
            this.Offset = new Long(source.Offset);
        }
        if (source.Limit != null) {
            this.Limit = new Long(source.Limit);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "SdkAppId", this.SdkAppId);
        this.setParamSimple(map, prefix + "Offset", this.Offset);
        this.setParamSimple(map, prefix + "Limit", this.Limit);

    }
}
